@@ -93,7 +93,7 @@ static void      gpm_applet_update_tooltip        (GpmBrightnessApplet *applet);
 static void      gpm_applet_update_popup_level    (GpmBrightnessApplet *applet);
 static gboolean  gpm_applet_plus_cb               (GtkWidget *w, GpmBrightnessApplet *applet);
 static gboolean  gpm_applet_minus_cb              (GtkWidget *w, GpmBrightnessApplet *applet);
-static gboolean  gpm_applet_key_press_cb          (GpmBrightnessApplet *applet, GdkEventKey *event);
+static gboolean  gpm_applet_key_press_cb          (GtkWidget *popup, GdkEventKey *event, GpmBrightnessApplet *applet);
 static gboolean  gpm_applet_scroll_cb             (GpmBrightnessApplet *applet, GdkEventScroll *event);
 static gboolean  gpm_applet_slide_cb              (GtkWidget *w, GpmBrightnessApplet *applet);
 static void      gpm_applet_create_popup          (GpmBrightnessApplet *applet);
@@ -344,9 +344,10 @@ static gboolean
 gpm_applet_destroy_popup_cb (GpmBrightnessApplet *applet)
 {
 	if (applet->popup != NULL) {
-		gtk_widget_set_parent (applet->popup, NULL);
 		gtk_widget_destroy (applet->popup);
 		applet->popup = NULL;
+		applet->popped = FALSE;
+		gpm_applet_update_tooltip (applet);
 	}
 	return TRUE;
 }
@@ -460,7 +461,7 @@ gpm_applet_slide_cb (GtkWidget *w, GpmBrightnessApplet *applet)
  * mainly escape to unpop and arrows to change brightness
  **/
 static gboolean
-gpm_applet_key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
+gpm_applet_key_press_cb (GtkWidget *popup, GdkEventKey *event, GpmBrightnessApplet *applet)
 {
 	int i;
 	
@@ -472,15 +473,10 @@ gpm_applet_key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
 	case GDK_KEY_space:
 	case GDK_KEY_KP_Space:
 	case GDK_KEY_Escape:
-		/* if yet popped, release focus and hide then redraw applet unselected */
+		/* if yet popped, hide */
 		if (applet->popped) {
-			gdk_keyboard_ungrab (GDK_CURRENT_TIME);
-			gdk_pointer_ungrab (GDK_CURRENT_TIME);
-			gtk_grab_remove (GTK_WIDGET(applet));
-			gtk_widget_set_state_flags (GTK_WIDGET(applet), GTK_STATE_FLAG_NORMAL, TRUE);
 			gtk_widget_hide (applet->popup);
 			applet->popped = FALSE;
-			gpm_applet_draw_cb (applet);
 			gpm_applet_update_tooltip (applet);
 			return TRUE;
 		} else {
@@ -560,21 +556,21 @@ on_popup_button_press (GtkWidget      *widget,
                        GdkEventButton *event,
                        GpmBrightnessApplet *applet)
 {
-        GtkWidget *event_widget;
+	GtkWidget *event_widget;
 
-        if (event->type != GDK_BUTTON_PRESS) {
-                return FALSE;
-        }
-        event_widget = gtk_get_event_widget ((GdkEvent *)event);
-        g_debug ("Button press: %p dock=%p", event_widget, widget);
-        if (event_widget == widget) {
-                gtk_widget_hide (applet->popup);
-                applet->popped = FALSE;
-                gpm_applet_update_tooltip (applet);
-                return TRUE;
-        }
+	if (event->type != GDK_BUTTON_PRESS) {
+		return FALSE;
+	}
+	event_widget = gtk_get_event_widget ((GdkEvent *)event);
+	g_debug ("Button press: %p dock=%p", event_widget, widget);
+	if (event_widget == widget) {
+		gtk_widget_hide (applet->popup);
+		applet->popped = FALSE;
+		gpm_applet_update_tooltip (applet);
+		return TRUE;
+	}
 
-        return FALSE;
+	return FALSE;
 }
 
 /**
@@ -636,12 +632,12 @@ gpm_applet_create_popup (GpmBrightnessApplet *applet)
 	gtk_window_set_type_hint (GTK_WINDOW(applet->popup), GDK_WINDOW_TYPE_HINT_UTILITY);
 	gtk_container_add (GTK_CONTAINER(applet->popup), frame);
 
-        /* window events */
-        g_signal_connect (G_OBJECT(applet->popup), "button-press-event",
-                          G_CALLBACK (on_popup_button_press), applet);
+	/* window events */
+	g_signal_connect (G_OBJECT(applet->popup), "button-press-event",
+	                  G_CALLBACK (on_popup_button_press), applet);
 
-        g_signal_connect (G_OBJECT(applet->popup), "key-press-event",
-                          G_CALLBACK(gpm_applet_key_press_cb), applet);
+	g_signal_connect (G_OBJECT(applet->popup), "key-press-event",
+	                  G_CALLBACK(gpm_applet_key_press_cb), applet);
 
 	/* Set volume control frame, slider and toplevel window to follow panel volume control theme */
 	GtkWidget *toplevel = gtk_widget_get_toplevel (frame);
@@ -676,7 +672,7 @@ gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 		return FALSE;
 	}
 
-	/* if yet popped, release focus and hide then redraw applet unselected */
+	/* if yet popped, release focus and hide */
 	if (applet->popped) {
 		gtk_widget_hide (applet->popup);
 		applet->popped = FALSE;
@@ -998,8 +994,7 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 
 	/* Add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
-
+	                                   GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* monitor the daemon */
 	applet->bus_watch_id =
@@ -1016,6 +1011,7 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 
 	/* prepare */
 	mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet), MATE_PANEL_APPLET_EXPAND_MINOR);
+	gtk_widget_set_events (GTK_WIDGET (applet), GDK_SCROLL_MASK);
 
 	/* show */
 	gtk_widget_show_all (GTK_WIDGET(applet));
@@ -1030,9 +1026,6 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 	g_signal_connect (G_OBJECT(applet), "scroll-event",
 			  G_CALLBACK(gpm_applet_scroll_cb), NULL);
 
-	g_signal_connect (G_OBJECT(applet), "key-press-event",
-			  G_CALLBACK(gpm_applet_key_press_cb), NULL);
-
 	/* We use g_signal_connect_after because letting the panel draw
 	 * the background is the only way to have the correct
 	 * background when a theme defines a background picture. */
